@@ -233,10 +233,11 @@ TotemPlParserResult
 totem_pl_parser_add_rss (TotemPlParser *parser,
 			 GFile *file,
 			 GFile *base_file,
+			 TotemPlParseData *parse_data,
 			 gpointer data)
 {
-#ifndef HAVE_CAMEL
-	WARN_NO_CAMEL;
+#ifndef HAVE_GMIME
+	WARN_NO_GMIME;
 #else
 	xml_node_t* doc, *channel;
 	char *contents;
@@ -277,7 +278,7 @@ totem_pl_parser_add_rss (TotemPlParser *parser,
 	xml_parser_free_tree (doc);
 
 	return TOTEM_PL_PARSER_RESULT_SUCCESS;
-#endif /* !HAVE_CAMEL */
+#endif /* !HAVE_GMIME */
 }
 
 /* http://www.apple.com/itunes/store/podcaststechspecs.html */
@@ -285,10 +286,11 @@ TotemPlParserResult
 totem_pl_parser_add_itpc (TotemPlParser *parser,
 			  GFile *file,
 			  GFile *base_file,
+			  TotemPlParseData *parse_data,
 			  gpointer data)
 {
-#ifndef HAVE_CAMEL
-	WARN_NO_CAMEL;
+#ifndef HAVE_GMIME
+	WARN_NO_GMIME;
 #else
 	TotemPlParserResult ret;
 	char *uri, *new_uri, *uri_scheme;
@@ -303,22 +305,23 @@ totem_pl_parser_add_itpc (TotemPlParser *parser,
 	new_file = g_file_new_for_uri (new_uri);
 	g_free (new_uri);
 
-	ret = totem_pl_parser_add_rss (parser, new_file, base_file, data);
+	ret = totem_pl_parser_add_rss (parser, new_file, base_file, parse_data, data);
 
 	g_object_unref (new_file);
 
 	return ret;
-#endif /* !HAVE_CAMEL */
+#endif /* !HAVE_GMIME */
 }
 
 TotemPlParserResult
 totem_pl_parser_add_zune (TotemPlParser *parser,
 			  GFile *file,
 			  GFile *base_file,
+			  TotemPlParseData *parse_data,
 			  gpointer data)
 {
-#ifndef HAVE_CAMEL
-	WARN_NO_CAMEL;
+#ifndef HAVE_GMIME
+	WARN_NO_GMIME;
 #else
 	TotemPlParserResult ret;
 	char *uri, *new_uri;
@@ -341,12 +344,12 @@ totem_pl_parser_add_zune (TotemPlParser *parser,
 	new_file = g_file_new_for_uri (new_uri);
 	g_free (uri);
 
-	ret = totem_pl_parser_add_rss (parser, new_file, base_file, data);
+	ret = totem_pl_parser_add_rss (parser, new_file, base_file, parse_data, data);
 
 	g_object_unref (new_file);
 
 	return ret;
-#endif /* !HAVE_CAMEL */
+#endif /* !HAVE_GMIME */
 }
 
 /* Atom docs:
@@ -483,10 +486,11 @@ TotemPlParserResult
 totem_pl_parser_add_atom (TotemPlParser *parser,
 			  GFile *file,
 			  GFile *base_file,
+			  TotemPlParseData *parse_data,
 			  gpointer data)
 {
-#ifndef HAVE_CAMEL
-	WARN_NO_CAMEL;
+#ifndef HAVE_GMIME
+	WARN_NO_GMIME;
 #else
 	xml_node_t* doc;
 	char *contents, *uri;
@@ -517,17 +521,18 @@ totem_pl_parser_add_atom (TotemPlParser *parser,
 	xml_parser_free_tree (doc);
 
 	return TOTEM_PL_PARSER_RESULT_SUCCESS;
-#endif /* !HAVE_CAMEL */
+#endif /* !HAVE_GMIME */
 }
 
 TotemPlParserResult
 totem_pl_parser_add_xml_feed (TotemPlParser *parser,
 			      GFile *file,
 			      GFile *base_file,
+			      TotemPlParseData *parse_data,
 			      gpointer data)
 {
-#ifndef HAVE_CAMEL
-	WARN_NO_CAMEL;
+#ifndef HAVE_GMIME
+	WARN_NO_GMIME;
 #else
 	guint len;
 
@@ -537,14 +542,14 @@ totem_pl_parser_add_xml_feed (TotemPlParser *parser,
 	len = strlen (data);
 
 	if (totem_pl_parser_is_rss (data, len) != FALSE)
-		return totem_pl_parser_add_rss (parser, file, base_file, data);
+		return totem_pl_parser_add_rss (parser, file, base_file, parse_data, data);
 	if (totem_pl_parser_is_atom (data, len) != FALSE)
-		return totem_pl_parser_add_atom (parser, file, base_file, data);
+		return totem_pl_parser_add_atom (parser, file, base_file, parse_data, data);
 	if (totem_pl_parser_is_opml (data, len) != FALSE)
-		return totem_pl_parser_add_opml (parser, file, base_file, data);
+		return totem_pl_parser_add_opml (parser, file, base_file, parse_data, data);
 
 	return TOTEM_PL_PARSER_RESULT_UNHANDLED;
-#endif /* !HAVE_CAMEL */
+#endif /* !HAVE_GMIME */
 }
 
 /* From libgsf's gsf-utils.h */
@@ -714,10 +719,11 @@ TotemPlParserResult
 totem_pl_parser_add_itms (TotemPlParser *parser,
 			  GFile *file,
 			  GFile *base_file,
+			  TotemPlParseData *parse_data,
 			  gpointer data)
 {
-#ifndef HAVE_CAMEL
-	WARN_NO_CAMEL;
+#ifndef HAVE_GMIME
+	WARN_NO_GMIME;
 #else
 	char *contents, *uncompressed, *itms_uri;
 	GFile *itms_file, *feed_file;
@@ -773,11 +779,11 @@ totem_pl_parser_add_itms (TotemPlParser *parser,
 
 	DEBUG(feed_file, g_print ("Found feed URI: %s\n", uri));
 
-	ret = totem_pl_parser_add_rss (parser, feed_file, NULL, NULL);
+	ret = totem_pl_parser_add_rss (parser, feed_file, NULL, parse_data, NULL);
 	g_object_unref (feed_file);
 
 	return ret;
-#endif /* !HAVE_CAMEL */
+#endif /* !HAVE_GMIME */
 }
 
 gboolean
@@ -874,10 +880,11 @@ TotemPlParserResult
 totem_pl_parser_add_opml (TotemPlParser *parser,
 			  GFile *file,
 			  GFile *base_file,
+			  TotemPlParseData *parse_data,
 			  gpointer data)
 {
-#ifndef HAVE_CAMEL
-	WARN_NO_CAMEL;
+#ifndef HAVE_GMIME
+	WARN_NO_GMIME;
 #else
 	xml_node_t* doc;
 	char *contents, *uri;
@@ -908,7 +915,7 @@ totem_pl_parser_add_opml (TotemPlParser *parser,
 	xml_parser_free_tree (doc);
 
 	return TOTEM_PL_PARSER_RESULT_SUCCESS;
-#endif /* !HAVE_CAMEL */
+#endif /* !HAVE_GMIME */
 }
 
 #endif /* !TOTEM_PL_PARSER_MINI */
